summaryrefslogtreecommitdiffstats
path: root/src/usr
diff options
context:
space:
mode:
authornagurram-in <nagendra.g@in.ibm.com>2017-01-04 15:06:26 -0600
committerWilliam G. Hoffa <wghoffa@us.ibm.com>2017-01-05 15:18:22 -0500
commitfdef37827ef440d4821298b2b7923387530b9b26 (patch)
tree0ce8e5dfbff42c8f7b8b97d040289f283b3aa852 /src/usr
parent872acfd22f47d1eb77d695ff279b17e57924675d (diff)
downloadtalos-hostboot-fdef37827ef440d4821298b2b7923387530b9b26.tar.gz
talos-hostboot-fdef37827ef440d4821298b2b7923387530b9b26.zip
HDAT Fixes for Witherspoon
Change-Id: I57b13cbef7c5460ebcfda45493cf5ef03dcb8ce3 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/34376 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: William G. Hoffa <wghoffa@us.ibm.com>
Diffstat (limited to 'src/usr')
-rwxr-xr-xsrc/usr/hdat/hdatmsarea.C31
-rw-r--r--src/usr/hdat/hdatnaca.C5
-rw-r--r--src/usr/hdat/hdatpcrd.C13
3 files changed, 29 insertions, 20 deletions
diff --git a/src/usr/hdat/hdatnaca.C b/src/usr/hdat/hdatnaca.C
index 6ad0e9307..520a85022 100644
--- a/src/usr/hdat/hdatnaca.C
+++ b/src/usr/hdat/hdatnaca.C
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2016 */
+/* Contributors Listed Below - COPYRIGHT 2016,2017 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -34,6 +34,7 @@
using namespace TARGETING;
+#define LID_SPACE 128*MEGABYTE //Bounded lid space blocked for building hdat structs.
namespace HDAT
{
extern trace_desc_t *g_trac_hdat;
@@ -57,7 +58,7 @@ errlHndl_t hdatGetNacaFromMem(hdatNaca_t &o_naca)
// Mapping the uncompressed region. HDAT areas are at the hrmor address
// + the naca offset so we are reading the entire area of 256 MB.
l_virtualAddress = mm_block_map(reinterpret_cast<void*>(l_hrmor),
- l_hrmor );
+ LID_SPACE );
// Reading the data at hrmor + Naca offset
hdatNaca_t* l_naca = reinterpret_cast<hdatNaca_t*>(
diff --git a/src/usr/hdat/hdatpcrd.C b/src/usr/hdat/hdatpcrd.C
index 8df9b615c..6796e63b3 100644
--- a/src/usr/hdat/hdatpcrd.C
+++ b/src/usr/hdat/hdatpcrd.C
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2016 */
+/* Contributors Listed Below - COPYRIGHT 2016,2017 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -606,8 +606,17 @@ errlHndl_t HdatPcrd::hdatSetProcessorInfo(
}
//set supported stop level
+ TARGETING::Target *l_pSysTarget = NULL;
+ (void) TARGETING::targetService().getTopLevelTarget(l_pSysTarget);
+ if(l_pSysTarget == NULL)
+ {
+ HDAT_ERR("Error in getting Top Level Target");
+ assert(l_pSysTarget != NULL);
+ }
+
iv_spPcrd->hdatChipData.hdatPcrdStopLevelSupport =
- i_pProcTarget->getAttr<TARGETING::ATTR_SUPPORTED_STOP_STATES>();
+ l_pSysTarget->getAttr<TARGETING::ATTR_SUPPORTED_STOP_STATES>();
+
}
while(0);
return l_errl;
OpenPOWER on IntegriCloud
diff --git a/src/usr/hdat/hdatmsarea.C b/src/usr/hdat/hdatmsarea.C
index f2031c08d..4dc614b2f 100755
--- a/src/usr/hdat/hdatmsarea.C
+++ b/src/usr/hdat/hdatmsarea.C
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2016 */
+/* Contributors Listed Below - COPYRIGHT 2016,2017 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -50,21 +50,20 @@ uint32_t HdatMsArea::cv_actualCnt;
static vpdData cvpdData[] =
{
-// { CVPD::VINI, CVPD::RT },
- { CVPD::VINI, CVPD::DR },
- { CVPD::VINI, CVPD::FN },
- { CVPD::VINI, CVPD::PN },
- { CVPD::VINI, CVPD::SN },
- { CVPD::VINI, CVPD::CC },
-// { CVPD::VINI, CVPD::PR },
- //{ CVPD::VINI, CVPD::SZ },
- { CVPD::VINI, CVPD::HE },
- { CVPD::VINI, CVPD::CT },
- { CVPD::VINI, CVPD::HW },
- // { CVPD::VINI, CVPD::B3 },
- // { CVPD::VINI, CVPD::B4 },
- // { CVPD::VINI, CVPD::B7 },
- { CVPD::VINI, CVPD::PF },
+// { MVPD::VINI, MVPD::RT },
+ { MVPD::VINI, MVPD::DR },
+ { MVPD::VINI, MVPD::FN },
+ { MVPD::VINI, MVPD::PN },
+ { MVPD::VINI, MVPD::SN },
+ { MVPD::VINI, MVPD::CC },
+// { MVPD::VINI, MVPD::PR },
+ //{ MVPD::VINI, MVPD::SZ },
+ { MVPD::VINI, MVPD::HE },
+ { MVPD::VINI, MVPD::CT },
+ { MVPD::VINI, MVPD::HW },
+ // { MVPD::VINI, MVPD::B3 },
+ // { MVPD::VINI, MVPD::B4 },
+ // { MVPD::VINI, MVPD::B7 },
};
const HdatKeywordInfo l_cvpdKeywords[] =